Frog = {}
Frog.__index = Frog

-- constant for all frog instances
Frog.NUM_FRAMES = 8 -- number of frames in the animation
Frog.IMG = love.graphics.newImage("frog.png")
Frog.FRAMES = {}
for i = 0, (Frog.NUM_FRAMES - 1) do
	Frog.FRAMES[i] = love.graphics.newQuad(16*i, 0, 16, 16, 128, 16)
end

function Frog.new(x, y)
	local self = setmetatable({}, Frog)
	self.frame = 0 -- current frame
	self.facing = 1 -- 1 = right, -1 = left
	self.x = x
	self.y = y
	self.xvelocity = 0 -- measured in pixels per second
	self.yvelocity = 0
	self.yaccel = 1000 -- measured in pixels per second per second
	self.onGround = false
	
	return self
end

function Frog:update(dt)
	self.frame = (15 * love.timer.getTime()) % 8 -- 15 frames per second, 8 frames
	self:input() -- receive user input
	
	-- apply acceleration and velocity, set coordinates accordingly
	self.yvelocity = self.yvelocity + (self.yaccel * dt)
	self.x = self.x + (self.xvelocity * dt)
	self.y = self.y + (self.yvelocity * dt)
	
	if self.y >= lineY - 1 then
		self.y = lineY - 1
	end
	
	if not self.onGround and self.y >= lineY - 1 then
		self.onGround = true
		self.yvelocity = 0
	end
end

function Frog:draw()
	-- offset to the center at his feet
	love.graphics.drawq(self.IMG, self.FRAMES[math.floor(self.frame)], math.floor(self.x), math.floor(self.y), 0, self.facing, 1, 8, 16)
end

function Frog:input()
	if love.keyboard.isDown("right") then
		self.facing = 1
		self.xvelocity = 100
	elseif love.keyboard.isDown("left") then
		self.facing = -1
		self.xvelocity = -100
	else
		self.xvelocity = 0
	end
	if self.onGround and love.keyboard.isDown("up") then
		self.onGround = false
		self.yvelocity = -300
	end
end
